==> haskell-bzlib-0.5.0.5-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-bzlib.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bzlib
version: 0.5.0.5
id: bzlib-0.5.0.5-I5HFtx2qcsm7rM1vX9uO9x
key: bzlib-0.5.0.5-I5HFtx2qcsm7rM1vX9uO9x
license: BSD-3-Clause
copyright: (c) 2006-2015 Duncan Coutts
maintainer: Duncan Coutts <duncan@community.haskell.org>
author: Duncan Coutts <duncan@community.haskell.org>
synopsis: Compression and decompression in the bzip2 format
description:
    This package provides a pure interface for compressing and
    decompressing streams of data represented as lazy
    '\''ByteString'\''s. It uses the bz2 C library so it has high
    performance.
    .
    It provides a convenient high level API suitable for most
    tasks and for the few cases where more control is needed it
    provides access to the full bzip2 feature set.
category: Codec
abi: d89a9a6d431375f3cd9be882e3f31c98
exposed: True
exposed-modules:
    Codec.Compression.BZip Codec.Compression.BZip.Internal
hidden-modules: Codec.Compression.BZip.Stream
import-dirs: /usr/lib/ghc-8.4.3/site-local/bzlib-0.5.0.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/bzlib-0.5.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/bzlib-0.5.0.5
hs-libraries: HSbzlib-0.5.0.5-I5HFtx2qcsm7rM1vX9uO9x
extra-libraries:
    bz2
includes:
    bzlib.h
depends:
    base-4.11.1.0 bytestring-0.10.8.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
haddock-interfaces: /usr/share/doc/haskell-bzlib/html/bzlib.haddock
haddock-html: /usr/share/doc/haskell-bzlib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bzlib-0.5.0.5-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-bzlib.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bzlib
version: 0.5.0.5
id: bzlib-0.5.0.5-8TMEZNLRAIMKxXCedq0SW1
key: bzlib-0.5.0.5-8TMEZNLRAIMKxXCedq0SW1
license: BSD-3-Clause
copyright: (c) 2006-2015 Duncan Coutts
maintainer: Duncan Coutts <duncan@community.haskell.org>
author: Duncan Coutts <duncan@community.haskell.org>
synopsis: Compression and decompression in the bzip2 format
description:
    This package provides a pure interface for compressing and
    decompressing streams of data represented as lazy
    '\''ByteString'\''s. It uses the bz2 C library so it has high
    performance.
    .
    It provides a convenient high level API suitable for most
    tasks and for the few cases where more control is needed it
    provides access to the full bzip2 feature set.
category: Codec
abi: 98dde0d19e8405b0709d2d75694a593a
exposed: True
exposed-modules:
    Codec.Compression.BZip Codec.Compression.BZip.Internal
hidden-modules: Codec.Compression.BZip.Stream
import-dirs: /usr/lib/ghc-8.6.1/site-local/bzlib-0.5.0.5
library-dirs: /usr/lib/ghc-8.6.1/site-local/bzlib-0.5.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/bzlib-0.5.0.5
hs-libraries: HSbzlib-0.5.0.5-8TMEZNLRAIMKxXCedq0SW1
extra-libraries:
    bz2
includes:
    bzlib.h
depends:
    base-4.12.0.0 bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-bzlib/html/bzlib.haddock
haddock-html: /usr/share/doc/haskell-bzlib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
